function [divergence] = diver_comp(data_ref, data_test, betas_ref, betas_test, L)
[Nobs , Nvars] = size(data_ref);

a = zeros(1, Nvars);

    for i = 1:Nvars
        % Return row vector of std.s of the ref and test sets' variables 
        sd_ref = std(data_ref(:,i));              % std. dev of reference set
        sd_test = std(data_test(:,i));            % std. dev of test set 

        % Return beta coeficients of ref and test sets' in matrix format 
        b_ref = betas_ref(:,i);
        b_test = betas_test(:,i);

        % Return the mean of the concatenate lagged variables 
        [X_ref, ~] = ts_lag(data_ref, L, i); 
        [X_test, ~] = ts_lag(data_test, L, i); 

        mcon_ref  = mean(X_ref)';
        mcon_test = mean(X_test)';

        % Compute divergence 
        d_ab = divergence(sd_ref, sd_test, b_test, b_ref, mcon_ref);    % divergence 'ref' to 'test'
        d_ba = divergence(sd_test, sd_ref, b_test, b_ref, mcon_test);    % divergence 'test' to 'ref'          
        a(i) = max([d_ab; d_ba]);
    end
    
    function [a] = divergence(sd_ref, sd_test, b_test, b_ref, mconc)
    a = - ( log( abs( sigma_ref)) - log( abs(sigma_test))) ...
        - 1/2 * ( 1 - ( 1 / sigma_test.^2) * ...
        (sigma_ref.^2 + (beta_ref - beta_test)' * mconcc).^2);
    end
end

function [a] = divergence(sd_ref, sd_test, b_test, b_ref, mconc)
    a = - ( log( abs( sigma_ref)) - log( abs(sigma_test))) ...
        - 1/2 * ( 1 - ( 1 / sigma_test.^2) * ...
        (sigma_ref.^2 + (beta_ref - beta_test)' * mconcc).^2);
end